@@ -1,6 +1,7 @@
 from math import sqrt
 import json
 
+
 class Statistics:
     def __init__(self):
         self.number_of_successes = 0
@@ -22,12 +23,8 @@ class Statistics:
         return self.number_of_successes / self.sample_size()
 
     def uncertainty(self):
-        assert(self.sample_size != 0)
-        return sqrt(
-            self.failure_rate() 
-            * self.success_rate() 
-            / self.sample_size()
-        )
+        assert self.sample_size != 0
+        return sqrt(self.failure_rate() * self.success_rate() / self.sample_size())
 
     def to_json(self):
         return json.dumps(
@@ -44,11 +41,10 @@ class Statistics:
         )
 
     def __repr__(self):
-        string =  "Statistics\n"
+        string = "Statistics\n"
         string += "----------\n"
         string += f"sample size: {self.sample_size()}\n"
         string += f"failure rate: {self.failure_rate()}\n"
         string += f"success rate: {self.success_rate()}\n"
         string += f"uncertainty: {self.uncertainty()}"
         return string
-
