@@ -1,9 +1,9 @@
 use crate::{PyBinaryVector, PyLinearCode};
-use ldpc::decoders::FlipDecoder;
-use ldpc::LinearCode;
+use ldpc::classical::decoders::FlipDecoder;
+use ldpc::classical::LinearCode;
 use pyo3::prelude::*;
 
-#[pyclass(name = FlipDecoder)]
+#[pyclass(name = "FlipDecoder")]
 pub struct PyFlipDecoder {
     pub(crate) inner: FlipDecoder<LinearCode>,
     tag: String,
